@@ -13,8 +13,15 @@ import (
 	yaml "gopkg.in/yaml.v3"
 )
 
+type xmlPreferences struct {
+	AttributePrefix string
+	ContentName     string
+}
+
 var log = logging.MustGetLogger("yq-lib")
 
+var PrettyPrintExp = `(... | (select(tag != "!!str"), select(tag == "!!str") | select(test("(?i)^(y|yes|n|no|on|off)$") | not))  ) style=""`
+
 // GetLogger returns the yq logger instance.
 func GetLogger() *logging.Logger {
 	return log
@@ -229,6 +236,22 @@ func createScalarNode(value interface{}, stringValue string) *yaml.Node {
 	return node
 }
 
+func headAndLineComment(node *yaml.Node) string {
+	return headComment(node) + lineComment(node)
+}
+
+func headComment(node *yaml.Node) string {
+	return strings.Replace(node.HeadComment, "#", "", 1)
+}
+
+func lineComment(node *yaml.Node) string {
+	return strings.Replace(node.LineComment, "#", "", 1)
+}
+
+func footComment(node *yaml.Node) string {
+	return strings.Replace(node.FootComment, "#", "", 1)
+}
+
 func createValueOperation(value interface{}, stringValue string) *Operation {
 	var node *yaml.Node = createScalarNode(value, stringValue)
 
