@@ -4,7 +4,6 @@ import (
 	"bufio"
 	"container/list"
 	"fmt"
-	"io/ioutil"
 	"os"
 
 	"gopkg.in/yaml.v3"
@@ -12,13 +11,14 @@ import (
 
 type loadPrefs struct {
 	loadAsString bool
+	decoder      Decoder
 }
 
 func loadString(filename string) (*CandidateNode, error) {
 	// ignore CWE-22 gosec issue - that's more targeted for http based apps that run in a public directory,
 	// and ensuring that it's not possible to give a path to a file outside that directory.
 
-	filebytes, err := ioutil.ReadFile(filename) // #nosec
+	filebytes, err := os.ReadFile(filename) // #nosec
 	if err != nil {
 		return nil, err
 	}
@@ -26,7 +26,7 @@ func loadString(filename string) (*CandidateNode, error) {
 	return &CandidateNode{Node: &yaml.Node{Kind: yaml.ScalarNode, Tag: "!!str", Value: string(filebytes)}}, nil
 }
 
-func loadYaml(filename string) (*CandidateNode, error) {
+func loadYaml(filename string, decoder Decoder) (*CandidateNode, error) {
 
 	file, err := os.Open(filename) // #nosec
 	if err != nil {
@@ -34,7 +34,7 @@ func loadYaml(filename string) (*CandidateNode, error) {
 	}
 	reader := bufio.NewReader(file)
 
-	documents, err := readDocuments(reader, filename, 0)
+	documents, err := readDocuments(reader, filename, 0, decoder)
 	if err != nil {
 		return nil, err
 	}
@@ -83,7 +83,7 @@ func loadYamlOperator(d *dataTreeNavigator, context Context, expressionNode *Exp
 		if loadPrefs.loadAsString {
 			contentsCandidate, err = loadString(filename)
 		} else {
-			contentsCandidate, err = loadYaml(filename)
+			contentsCandidate, err = loadYaml(filename, loadPrefs.decoder)
 		}
 		if err != nil {
 			return Context{}, fmt.Errorf("Failed to load %v: %w", filename, err)
