@@ -344,6 +344,14 @@ var multiplyOperatorScenarios = []expressionScenario{
 			"D0, P[a], (!!map)::{thing: two, cat: frog}\n",
 		},
 	},
+	{
+		description: "Merge, only new fields",
+		document:    `{a: {thing: one, cat: frog}, b: {missing: two, thing: two}}`,
+		expression:  `.a *n .b`,
+		expected: []string{
+			"D0, P[a], (!!map)::{thing: one, cat: frog, missing: two}\n",
+		},
+	},
 	{
 		skipDoc:    true,
 		document:   `{a: [{thing: one}], b: [{missing: two, thing: two}]}`,
@@ -352,6 +360,14 @@ var multiplyOperatorScenarios = []expressionScenario{
 			"D0, P[a], (!!seq)::[{thing: two}]\n",
 		},
 	},
+	{
+		skipDoc:    true,
+		document:   `{a: [{thing: one}], b: [{missing: two, thing: two}]}`,
+		expression: `.a *nd .b`,
+		expected: []string{
+			"D0, P[a], (!!seq)::[{thing: one, missing: two}]\n",
+		},
+	},
 	{
 		skipDoc:    true,
 		document:   `{a: {array: [1]}, b: {}}`,
@@ -376,6 +392,16 @@ var multiplyOperatorScenarios = []expressionScenario{
 			"D0, P[a], (!!map)::{thing: [1, 2, 3, 4]}\n",
 		},
 	},
+	{
+		description:    "Merge, only new fields, appending arrays",
+		subdescription: "Append (+) with (n) has no effect.",
+		skipDoc:        true,
+		document:       `{a: {thing: [1,2]}, b: {thing: [3,4], another: [1]}}`,
+		expression:     `.a *n+ .b`,
+		expected: []string{
+			"D0, P[a], (!!map)::{thing: [1, 2], another: [1]}\n",
+		},
+	},
 	{
 		description:    "Merge, deeply merging arrays",
 		subdescription: "Merging arrays deeply means arrays are merge like objects, with indexes as their key. In this case, we merge the first item in the array, and do nothing with the second.",
@@ -441,5 +467,5 @@ func TestMultiplyOperatorScenarios(t *testing.T) {
 	for _, tt := range multiplyOperatorScenarios {
 		testScenario(t, &tt)
 	}
-	documentScenarios(t, "multiply-merge", multiplyOperatorScenarios)
+	documentOperatorScenarios(t, "multiply-merge", multiplyOperatorScenarios)
 }
